@@ -276,11 +276,26 @@ static NodeSet find_impl(xmlXPathContext* ctxt, const Glib::ustring& xpath)
 
   xmlNodeSet* nodeset = result->nodesetval;
   NodeSet nodes;
-  if( nodeset )
+  if( nodeset && !xmlXPathNodeSetIsEmpty(nodeset))
   {
-    nodes.reserve( nodeset->nodeNr );
-    for (int i = 0; i != nodeset->nodeNr; ++i)
-      nodes.push_back(static_cast<Node*>(nodeset->nodeTab[i]->_private));
+    const int count = xmlXPathNodeSetGetLength(nodeset);
+    nodes.reserve(count);
+    for (int i = 0; i != count; ++i)
+    {
+      xmlNode* cnode = xmlXPathNodeSetItem(nodeset, i);
+      if(cnode->type == XML_NAMESPACE_DECL)
+      {
+        //In this case we would cast it to a xmlNs*,
+        //but this C++ method only returns Nodes.
+        std::cerr << "Node::find_impl: ignoring an xmlNs object." << std::endl;
+        continue;
+      }
+      
+      //TODO: Check for other cnode->type values?
+  
+      Node* cppNode = static_cast<Node*>(cnode->_private);
+      nodes.push_back(cppNode);
+    }
   }
   else
   {
